summaryrefslogtreecommitdiff
path: root/src/jit
diff options
context:
space:
mode:
authorPat Gavlin <pgavlin@gmail.com>2016-12-08 16:57:14 -0800
committerGitHub <noreply@github.com>2016-12-08 16:57:14 -0800
commit4d8fb4130efd3a3c9d5a2f13f748a53381e20f9c (patch)
tree51b3566183247f0027b1f70a486dacf6afabc1b9 /src/jit
parent37c632e9628278e5e04d1c51b955df1eeee35084 (diff)
parent8b65d160640b0f9a761ca905610409fa5bc35372 (diff)
downloadcoreclr-4d8fb4130efd3a3c9d5a2f13f748a53381e20f9c.tar.gz
coreclr-4d8fb4130efd3a3c9d5a2f13f748a53381e20f9c.tar.bz2
coreclr-4d8fb4130efd3a3c9d5a2f13f748a53381e20f9c.zip
Merge pull request #8543 from pgavlin/VSO299207
Correct an assertion in LSRA.
Diffstat (limited to 'src/jit')
-rw-r--r--src/jit/lsra.cpp5
1 files changed, 2 insertions, 3 deletions
diff --git a/src/jit/lsra.cpp b/src/jit/lsra.cpp
index 6813beb288..249ab4a982 100644
--- a/src/jit/lsra.cpp
+++ b/src/jit/lsra.cpp
@@ -11788,15 +11788,14 @@ void LinearScan::verifyFinalAllocation()
interval->physReg = REG_NA;
interval->assignedReg = nullptr;
// regRegcord could be null if RefPosition is to be allocated a
// reg only if profitable.
if (regRecord != nullptr)
{
regRecord->assignedInterval = nullptr;
}
else
{
- assert(currentRefPosition->AllocateIfProfitable());
+ assert(!currentRefPosition->RequiresRegister());
}
}
}
@@ -11788,15 +11788,14 @@ void LinearScan::verifyFinalAllocation()
interval->physReg = REG_NA;
interval->assignedReg = nullptr;
- // regRegcord could be null if RefPosition is to be allocated a
- // reg only if profitable.
+ // regRegcord could be null if the RefPosition does not require a register.
if (regRecord != nullptr)
{